// Copyright 2020 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Package source_context aliases all exported identifiers in
// package "google.golang.org/protobuf/types/known/sourcecontextpb".
package source_context

import "google.golang.org/protobuf/types/known/sourcecontextpb"

type SourceContext = sourcecontextpb.SourceContext

var File_google_protobuf_source_context_proto = sourcecontextpb.File_google_protobuf_source_context_proto
