// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/recommendationengine/v1beta1/prediction_apikey_registry_service.proto

package recommendationengine

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	empty "github.com/golang/protobuf/ptypes/empty"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
	codes "google.golang.org/grpc/codes"
	status "google.golang.org/grpc/status"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Registered Api Key.
type PredictionApiKeyRegistration struct {
	// The API key.
	ApiKey               string   `protobuf:"bytes,1,opt,name=api_key,json=apiKey,proto3" json:"api_key,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *PredictionApiKeyRegistration) Reset()         { *m = PredictionApiKeyRegistration{} }
func (m *PredictionApiKeyRegistration) String() string { return proto.CompactTextString(m) }
func (*PredictionApiKeyRegistration) ProtoMessage()    {}
func (*PredictionApiKeyRegistration) Descriptor() ([]byte, []int) {
	return fileDescriptor_dc7c074fb118b00d, []int{0}
}

func (m *PredictionApiKeyRegistration) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PredictionApiKeyRegistration.Unmarshal(m, b)
}
func (m *PredictionApiKeyRegistration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PredictionApiKeyRegistration.Marshal(b, m, deterministic)
}
func (m *PredictionApiKeyRegistration) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PredictionApiKeyRegistration.Merge(m, src)
}
func (m *PredictionApiKeyRegistration) XXX_Size() int {
	return xxx_messageInfo_PredictionApiKeyRegistration.Size(m)
}
func (m *PredictionApiKeyRegistration) XXX_DiscardUnknown() {
	xxx_messageInfo_PredictionApiKeyRegistration.DiscardUnknown(m)
}

var xxx_messageInfo_PredictionApiKeyRegistration proto.InternalMessageInfo

func (m *PredictionApiKeyRegistration) GetApiKey() string {
	if m != nil {
		return m.ApiKey
	}
	return ""
}

// Request message for the `CreatePredictionApiKeyRegistration` method.
type CreatePredictionApiKeyRegistrationRequest struct {
	// Required. The parent resource path.
	// "projects/*/locations/global/catalogs/default_catalog/eventStores/default_event_store".
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. The prediction API key registration.
	PredictionApiKeyRegistration *PredictionApiKeyRegistration `protobuf:"bytes,2,opt,name=prediction_api_key_registration,json=predictionApiKeyRegistration,proto3" json:"prediction_api_key_registration,omitempty"`
	XXX_NoUnkeyedLiteral         struct{}                      `json:"-"`
	XXX_unrecognized             []byte                        `json:"-"`
	XXX_sizecache                int32                         `json:"-"`
}

func (m *CreatePredictionApiKeyRegistrationRequest) Reset() {
	*m = CreatePredictionApiKeyRegistrationRequest{}
}
func (m *CreatePredictionApiKeyRegistrationRequest) String() string {
	return proto.CompactTextString(m)
}
func (*CreatePredictionApiKeyRegistrationRequest) ProtoMessage() {}
func (*CreatePredictionApiKeyRegistrationRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_dc7c074fb118b00d, []int{1}
}

func (m *CreatePredictionApiKeyRegistrationRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreatePredictionApiKeyRegistrationRequest.Unmarshal(m, b)
}
func (m *CreatePredictionApiKeyRegistrationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreatePredictionApiKeyRegistrationRequest.Marshal(b, m, deterministic)
}
func (m *CreatePredictionApiKeyRegistrationRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreatePredictionApiKeyRegistrationRequest.Merge(m, src)
}
func (m *CreatePredictionApiKeyRegistrationRequest) XXX_Size() int {
	return xxx_messageInfo_CreatePredictionApiKeyRegistrationRequest.Size(m)
}
func (m *CreatePredictionApiKeyRegistrationRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreatePredictionApiKeyRegistrationRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreatePredictionApiKeyRegistrationRequest proto.InternalMessageInfo

func (m *CreatePredictionApiKeyRegistrationRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *CreatePredictionApiKeyRegistrationRequest) GetPredictionApiKeyRegistration() *PredictionApiKeyRegistration {
	if m != nil {
		return m.PredictionApiKeyRegistration
	}
	return nil
}

// Request message for the `ListPredictionApiKeyRegistrations`.
type ListPredictionApiKeyRegistrationsRequest struct {
	// Required. The parent placement resource name such as
	// "projects/1234/locations/global/catalogs/default_catalog/eventStores/default_event_store"
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Optional. Maximum number of results to return per page. If unset, the
	// service will choose a reasonable default.
	PageSize int32 `protobuf:"varint,2,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. The previous `ListPredictionApiKeyRegistration.nextPageToken`.
	PageToken            string   `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListPredictionApiKeyRegistrationsRequest) Reset() {
	*m = ListPredictionApiKeyRegistrationsRequest{}
}
func (m *ListPredictionApiKeyRegistrationsRequest) String() string { return proto.CompactTextString(m) }
func (*ListPredictionApiKeyRegistrationsRequest) ProtoMessage()    {}
func (*ListPredictionApiKeyRegistrationsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_dc7c074fb118b00d, []int{2}
}

func (m *ListPredictionApiKeyRegistrationsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListPredictionApiKeyRegistrationsRequest.Unmarshal(m, b)
}
func (m *ListPredictionApiKeyRegistrationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListPredictionApiKeyRegistrationsRequest.Marshal(b, m, deterministic)
}
func (m *ListPredictionApiKeyRegistrationsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListPredictionApiKeyRegistrationsRequest.Merge(m, src)
}
func (m *ListPredictionApiKeyRegistrationsRequest) XXX_Size() int {
	return xxx_messageInfo_ListPredictionApiKeyRegistrationsRequest.Size(m)
}
func (m *ListPredictionApiKeyRegistrationsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListPredictionApiKeyRegistrationsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListPredictionApiKeyRegistrationsRequest proto.InternalMessageInfo

func (m *ListPredictionApiKeyRegistrationsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListPredictionApiKeyRegistrationsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

func (m *ListPredictionApiKeyRegistrationsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

// Response message for the `ListPredictionApiKeyRegistrations`.
type ListPredictionApiKeyRegistrationsResponse struct {
	// The list of registered API keys.
	PredictionApiKeyRegistrations []*PredictionApiKeyRegistration `protobuf:"bytes,1,rep,name=prediction_api_key_registrations,json=predictionApiKeyRegistrations,proto3" json:"prediction_api_key_registrations,omitempty"`
	// If empty, the list is complete. If nonempty, pass the token to the next
	// request's `ListPredictionApiKeysRegistrationsRequest.pageToken`.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListPredictionApiKeyRegistrationsResponse) Reset() {
	*m = ListPredictionApiKeyRegistrationsResponse{}
}
func (m *ListPredictionApiKeyRegistrationsResponse) String() string {
	return proto.CompactTextString(m)
}
func (*ListPredictionApiKeyRegistrationsResponse) ProtoMessage() {}
func (*ListPredictionApiKeyRegistrationsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_dc7c074fb118b00d, []int{3}
}

func (m *ListPredictionApiKeyRegistrationsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListPredictionApiKeyRegistrationsResponse.Unmarshal(m, b)
}
func (m *ListPredictionApiKeyRegistrationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListPredictionApiKeyRegistrationsResponse.Marshal(b, m, deterministic)
}
func (m *ListPredictionApiKeyRegistrationsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListPredictionApiKeyRegistrationsResponse.Merge(m, src)
}
func (m *ListPredictionApiKeyRegistrationsResponse) XXX_Size() int {
	return xxx_messageInfo_ListPredictionApiKeyRegistrationsResponse.Size(m)
}
func (m *ListPredictionApiKeyRegistrationsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListPredictionApiKeyRegistrationsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListPredictionApiKeyRegistrationsResponse proto.InternalMessageInfo

func (m *ListPredictionApiKeyRegistrationsResponse) GetPredictionApiKeyRegistrations() []*PredictionApiKeyRegistration {
	if m != nil {
		return m.PredictionApiKeyRegistrations
	}
	return nil
}

func (m *ListPredictionApiKeyRegistrationsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request message for `DeletePredictionApiKeyRegistration` method.
type DeletePredictionApiKeyRegistrationRequest struct {
	// Required. The API key to unregister including full resource path.
	// "projects/*/locations/global/catalogs/default_catalog/eventStores/default_event_store/predictionApiKeyRegistrations/<YOUR_API_KEY>"
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DeletePredictionApiKeyRegistrationRequest) Reset() {
	*m = DeletePredictionApiKeyRegistrationRequest{}
}
func (m *DeletePredictionApiKeyRegistrationRequest) String() string {
	return proto.CompactTextString(m)
}
func (*DeletePredictionApiKeyRegistrationRequest) ProtoMessage() {}
func (*DeletePredictionApiKeyRegistrationRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_dc7c074fb118b00d, []int{4}
}

func (m *DeletePredictionApiKeyRegistrationRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DeletePredictionApiKeyRegistrationRequest.Unmarshal(m, b)
}
func (m *DeletePredictionApiKeyRegistrationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DeletePredictionApiKeyRegistrationRequest.Marshal(b, m, deterministic)
}
func (m *DeletePredictionApiKeyRegistrationRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DeletePredictionApiKeyRegistrationRequest.Merge(m, src)
}
func (m *DeletePredictionApiKeyRegistrationRequest) XXX_Size() int {
	return xxx_messageInfo_DeletePredictionApiKeyRegistrationRequest.Size(m)
}
func (m *DeletePredictionApiKeyRegistrationRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_DeletePredictionApiKeyRegistrationRequest.DiscardUnknown(m)
}

var xxx_messageInfo_DeletePredictionApiKeyRegistrationRequest proto.InternalMessageInfo

func (m *DeletePredictionApiKeyRegistrationRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func init() {
	proto.RegisterType((*PredictionApiKeyRegistration)(nil), "google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistration")
	proto.RegisterType((*CreatePredictionApiKeyRegistrationRequest)(nil), "google.cloud.recommendationengine.v1beta1.CreatePredictionApiKeyRegistrationRequest")
	proto.RegisterType((*ListPredictionApiKeyRegistrationsRequest)(nil), "google.cloud.recommendationengine.v1beta1.ListPredictionApiKeyRegistrationsRequest")
	proto.RegisterType((*ListPredictionApiKeyRegistrationsResponse)(nil), "google.cloud.recommendationengine.v1beta1.ListPredictionApiKeyRegistrationsResponse")
	proto.RegisterType((*DeletePredictionApiKeyRegistrationRequest)(nil), "google.cloud.recommendationengine.v1beta1.DeletePredictionApiKeyRegistrationRequest")
}

func init() {
	proto.RegisterFile("google/cloud/recommendationengine/v1beta1/prediction_apikey_registry_service.proto", fileDescriptor_dc7c074fb118b00d)
}

var fileDescriptor_dc7c074fb118b00d = []byte{
	// 714 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xb4, 0x55, 0xcf, 0x6b, 0x13, 0x41,
	0x14, 0x66, 0xb7, 0xb6, 0xb5, 0x23, 0x22, 0xec, 0xc1, 0x86, 0xb4, 0xd2, 0xb8, 0x82, 0x34, 0xc1,
	0xee, 0xd0, 0x7a, 0x10, 0x56, 0x3c, 0xa4, 0x3f, 0x28, 0xa2, 0x87, 0xb2, 0x2d, 0x15, 0xa4, 0xb2,
	0x4c, 0x36, 0xaf, 0xdb, 0x69, 0x37, 0x33, 0xe3, 0xce, 0x24, 0x35, 0x95, 0x5e, 0xbc, 0x2b, 0x82,
	0x7f, 0x80, 0xe0, 0xd1, 0x8b, 0x47, 0xff, 0x87, 0x1e, 0xf5, 0xe4, 0x41, 0xf0, 0x20, 0x1e, 0xfc,
	0x17, 0xbc, 0xc8, 0xce, 0x6e, 0x6a, 0x2a, 0x71, 0xb3, 0x81, 0x7a, 0x4b, 0xde, 0xfb, 0xe6, 0x7b,
	0xef, 0xfb, 0xf2, 0x5e, 0x1e, 0xf2, 0x42, 0xce, 0xc3, 0x08, 0x70, 0x10, 0xf1, 0x76, 0x13, 0xc7,
	0x10, 0xf0, 0x56, 0x0b, 0x58, 0x93, 0x28, 0xca, 0x19, 0xb0, 0x90, 0x32, 0xc0, 0x9d, 0xc5, 0x06,
	0x28, 0xb2, 0x88, 0x45, 0x0c, 0x4d, 0x1a, 0x24, 0x09, 0x9f, 0x08, 0x7a, 0x00, 0x5d, 0x3f, 0x86,
	0x90, 0x4a, 0x15, 0x77, 0x7d, 0x09, 0x71, 0x87, 0x06, 0xe0, 0x88, 0x98, 0x2b, 0x6e, 0x55, 0x53,
	0x4e, 0x47, 0x73, 0x3a, 0x83, 0x38, 0x9d, 0x8c, 0xb3, 0x3c, 0x9b, 0x95, 0x27, 0x82, 0x62, 0xc2,
	0x18, 0x57, 0x1a, 0x24, 0x53, 0xa2, 0xf2, 0x5c, 0x5f, 0x76, 0x97, 0x42, 0xd4, 0xf4, 0x1b, 0xb0,
	0x47, 0x3a, 0x94, 0xc7, 0x19, 0x60, 0x26, 0x03, 0xe8, 0x6f, 0x8d, 0xf6, 0x2e, 0x86, 0x96, 0x50,
	0xdd, 0x2c, 0x39, 0xdd, 0xf7, 0x3a, 0x88, 0x28, 0x30, 0x95, 0x26, 0xec, 0x3b, 0x68, 0x76, 0xe3,
	0x54, 0x4b, 0x5d, 0xd0, 0x07, 0xd0, 0xf5, 0x52, 0x25, 0xba, 0xba, 0x35, 0x8d, 0x26, 0x89, 0xa0,
	0xfe, 0x01, 0x74, 0x4b, 0x46, 0xc5, 0x98, 0x9f, 0xf2, 0x26, 0x88, 0x06, 0xd9, 0x5f, 0x0c, 0x54,
	0x5d, 0x89, 0x81, 0x28, 0xc8, 0x7b, 0xef, 0xc1, 0xd3, 0x36, 0x48, 0x65, 0xcd, 0xa0, 0x09, 0x41,
	0x62, 0x60, 0x2a, 0x65, 0x59, 0x1e, 0xfb, 0x56, 0x37, 0xbd, 0x2c, 0x64, 0xbd, 0x32, 0xd0, 0xdc,
	0x59, 0x43, 0xfd, 0x3e, 0x47, 0x35, 0x4f, 0xc9, 0xac, 0x18, 0xf3, 0x97, 0x96, 0xd6, 0x9d, 0xc2,
	0x76, 0x3a, 0xb9, 0x6d, 0xcd, 0x8a, 0x9c, 0xac, 0xfd, 0xd2, 0x40, 0xf3, 0x0f, 0xa9, 0x54, 0x79,
	0x14, 0xb2, 0x90, 0xb4, 0x0a, 0x9a, 0x12, 0x24, 0x04, 0x5f, 0xd2, 0x23, 0xd0, 0x1a, 0xc6, 0x93,
	0xbc, 0xe1, 0x5d, 0x4c, 0xa2, 0x9b, 0xf4, 0x08, 0x2c, 0x1b, 0x21, 0x8d, 0x50, 0xfc, 0x00, 0x58,
	0x69, 0xac, 0x47, 0x61, 0x78, 0xfa, 0xe1, 0x56, 0x12, 0xb5, 0x7f, 0x18, 0xa8, 0x5a, 0xa0, 0x1f,
	0x29, 0x38, 0x93, 0x60, 0xbd, 0x36, 0x50, 0x65, 0x88, 0x9d, 0xb2, 0x64, 0x54, 0xc6, 0xce, 0xd3,
	0xcf, 0x6b, 0x79, 0x7e, 0x4a, 0xeb, 0x26, 0xba, 0xc2, 0xe0, 0x99, 0xf2, 0xfb, 0x94, 0x9a, 0x7a,
	0x9a, 0x2e, 0x27, 0xe1, 0x8d, 0x53, 0xa1, 0xab, 0xa8, 0xba, 0x0a, 0x11, 0x14, 0x9b, 0xa9, 0x69,
	0x74, 0x81, 0x91, 0x16, 0xf4, 0xdb, 0xae, 0x03, 0x4b, 0x5f, 0x27, 0x51, 0xe9, 0x1f, 0x04, 0x5d,
	0xeb, 0x83, 0x89, 0xec, 0xe1, 0x73, 0x6b, 0x6d, 0x8d, 0xe0, 0x4c, 0xe1, 0x35, 0x28, 0x9f, 0x97,
	0xdf, 0xf6, 0xfe, 0x8b, 0xcf, 0xdf, 0xdf, 0x98, 0x4d, 0xdb, 0x3f, 0xfd, 0x47, 0x7a, 0x9e, 0x4e,
	0xdc, 0x3d, 0x11, 0xf3, 0x7d, 0x08, 0x94, 0xc4, 0x35, 0x1c, 0xf1, 0x20, 0xf5, 0x1f, 0xd7, 0x70,
	0x40, 0x14, 0x89, 0x78, 0x98, 0x7c, 0x84, 0x0e, 0x30, 0xb5, 0xa9, 0x78, 0x0c, 0x12, 0xd7, 0x8e,
	0x71, 0xee, 0x2f, 0xe7, 0x1a, 0x35, 0xeb, 0xa3, 0x89, 0xae, 0x0f, 0x9d, 0x3e, 0x6b, 0x73, 0x04,
	0x69, 0x45, 0x77, 0xab, 0xbc, 0x75, 0xbe, 0xa4, 0xe9, 0x82, 0xd8, 0xa1, 0x36, 0x8f, 0x58, 0xff,
	0xdb, 0x3c, 0xeb, 0x97, 0x81, 0xec, 0xe1, 0xf3, 0x3c, 0xd2, 0xac, 0x15, 0x5e, 0x8f, 0xf2, 0xd5,
	0x1e, 0x6b, 0xef, 0x20, 0x38, 0x6b, 0xc9, 0x41, 0xe8, 0xa9, 0xaf, 0xf5, 0xa9, 0x4f, 0xb6, 0x66,
	0x54, 0xed, 0xf9, 0xd2, 0x71, 0xed, 0xb8, 0xfc, 0xe8, 0xa4, 0x7e, 0x63, 0xa0, 0x96, 0xb4, 0x2f,
	0x22, 0xa8, 0x74, 0x02, 0xde, 0xfa, 0x54, 0x77, 0xf6, 0x94, 0x12, 0xd2, 0xc5, 0xf8, 0xf0, 0xf0,
	0xf0, 0xaf, 0x24, 0x26, 0x6d, 0xb5, 0x97, 0x1e, 0xe4, 0x05, 0x11, 0x11, 0xb5, 0xcb, 0xe3, 0xd6,
	0xf2, 0x5b, 0x13, 0x2d, 0x04, 0xbc, 0x55, 0xdc, 0xb5, 0x0d, 0xe3, 0xf1, 0x93, 0x0c, 0x1c, 0xf2,
	0x88, 0xb0, 0xd0, 0xe1, 0x71, 0x88, 0x43, 0x60, 0xda, 0x1a, 0xfc, 0xa7, 0x64, 0x81, 0xd3, 0x7f,
	0x77, 0x50, 0xf2, 0x9d, 0x39, 0xee, 0xad, 0xad, 0xd4, 0xef, 0xbf, 0x37, 0xab, 0xeb, 0x69, 0x9d,
	0x15, 0xdd, 0x94, 0x77, 0x06, 0xbb, 0x96, 0x36, 0xb5, 0xbd, 0xb8, 0x9c, 0x10, 0x9d, 0xf4, 0xb0,
	0x3b, 0x1a, 0xbb, 0x33, 0x08, 0xbb, 0xb3, 0x9d, 0x16, 0xfd, 0x69, 0xde, 0x4a, 0xb1, 0xae, 0xab,
	0xc1, 0xae, 0x3b, 0x08, 0xed, 0xba, 0x19, 0xbc, 0x31, 0xa1, 0x85, 0xdd, 0xfe, 0x1d, 0x00, 0x00,
	0xff, 0xff, 0x75, 0xc7, 0x8e, 0x55, 0xd2, 0x08, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConnInterface

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion6

// PredictionApiKeyRegistryClient is the client API for PredictionApiKeyRegistry service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type PredictionApiKeyRegistryClient interface {
	// Register an API key for use with predict method.
	CreatePredictionApiKeyRegistration(ctx context.Context, in *CreatePredictionApiKeyRegistrationRequest, opts ...grpc.CallOption) (*PredictionApiKeyRegistration, error)
	// List the registered apiKeys for use with predict method.
	ListPredictionApiKeyRegistrations(ctx context.Context, in *ListPredictionApiKeyRegistrationsRequest, opts ...grpc.CallOption) (*ListPredictionApiKeyRegistrationsResponse, error)
	// Unregister an apiKey from using for predict method.
	DeletePredictionApiKeyRegistration(ctx context.Context, in *DeletePredictionApiKeyRegistrationRequest, opts ...grpc.CallOption) (*empty.Empty, error)
}

type predictionApiKeyRegistryClient struct {
	cc grpc.ClientConnInterface
}

func NewPredictionApiKeyRegistryClient(cc grpc.ClientConnInterface) PredictionApiKeyRegistryClient {
	return &predictionApiKeyRegistryClient{cc}
}

func (c *predictionApiKeyRegistryClient) CreatePredictionApiKeyRegistration(ctx context.Context, in *CreatePredictionApiKeyRegistrationRequest, opts ...grpc.CallOption) (*PredictionApiKeyRegistration, error) {
	out := new(PredictionApiKeyRegistration)
	err := c.cc.Invoke(ctx, "/google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistry/CreatePredictionApiKeyRegistration", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *predictionApiKeyRegistryClient) ListPredictionApiKeyRegistrations(ctx context.Context, in *ListPredictionApiKeyRegistrationsRequest, opts ...grpc.CallOption) (*ListPredictionApiKeyRegistrationsResponse, error) {
	out := new(ListPredictionApiKeyRegistrationsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistry/ListPredictionApiKeyRegistrations", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *predictionApiKeyRegistryClient) DeletePredictionApiKeyRegistration(ctx context.Context, in *DeletePredictionApiKeyRegistrationRequest, opts ...grpc.CallOption) (*empty.Empty, error) {
	out := new(empty.Empty)
	err := c.cc.Invoke(ctx, "/google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistry/DeletePredictionApiKeyRegistration", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// PredictionApiKeyRegistryServer is the server API for PredictionApiKeyRegistry service.
type PredictionApiKeyRegistryServer interface {
	// Register an API key for use with predict method.
	CreatePredictionApiKeyRegistration(context.Context, *CreatePredictionApiKeyRegistrationRequest) (*PredictionApiKeyRegistration, error)
	// List the registered apiKeys for use with predict method.
	ListPredictionApiKeyRegistrations(context.Context, *ListPredictionApiKeyRegistrationsRequest) (*ListPredictionApiKeyRegistrationsResponse, error)
	// Unregister an apiKey from using for predict method.
	DeletePredictionApiKeyRegistration(context.Context, *DeletePredictionApiKeyRegistrationRequest) (*empty.Empty, error)
}

// UnimplementedPredictionApiKeyRegistryServer can be embedded to have forward compatible implementations.
type UnimplementedPredictionApiKeyRegistryServer struct {
}

func (*UnimplementedPredictionApiKeyRegistryServer) CreatePredictionApiKeyRegistration(ctx context.Context, req *CreatePredictionApiKeyRegistrationRequest) (*PredictionApiKeyRegistration, error) {
	return nil, status.Errorf(codes.Unimplemented, "method CreatePredictionApiKeyRegistration not implemented")
}
func (*UnimplementedPredictionApiKeyRegistryServer) ListPredictionApiKeyRegistrations(ctx context.Context, req *ListPredictionApiKeyRegistrationsRequest) (*ListPredictionApiKeyRegistrationsResponse, error) {
	return nil, status.Errorf(codes.Unimplemented, "method ListPredictionApiKeyRegistrations not implemented")
}
func (*UnimplementedPredictionApiKeyRegistryServer) DeletePredictionApiKeyRegistration(ctx context.Context, req *DeletePredictionApiKeyRegistrationRequest) (*empty.Empty, error) {
	return nil, status.Errorf(codes.Unimplemented, "method DeletePredictionApiKeyRegistration not implemented")
}

func RegisterPredictionApiKeyRegistryServer(s *grpc.Server, srv PredictionApiKeyRegistryServer) {
	s.RegisterService(&_PredictionApiKeyRegistry_serviceDesc, srv)
}

func _PredictionApiKeyRegistry_CreatePredictionApiKeyRegistration_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreatePredictionApiKeyRegistrationRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(PredictionApiKeyRegistryServer).CreatePredictionApiKeyRegistration(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistry/CreatePredictionApiKeyRegistration",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(PredictionApiKeyRegistryServer).CreatePredictionApiKeyRegistration(ctx, req.(*CreatePredictionApiKeyRegistrationRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _PredictionApiKeyRegistry_ListPredictionApiKeyRegistrations_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListPredictionApiKeyRegistrationsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(PredictionApiKeyRegistryServer).ListPredictionApiKeyRegistrations(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistry/ListPredictionApiKeyRegistrations",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(PredictionApiKeyRegistryServer).ListPredictionApiKeyRegistrations(ctx, req.(*ListPredictionApiKeyRegistrationsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _PredictionApiKeyRegistry_DeletePredictionApiKeyRegistration_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(DeletePredictionApiKeyRegistrationRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(PredictionApiKeyRegistryServer).DeletePredictionApiKeyRegistration(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistry/DeletePredictionApiKeyRegistration",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(PredictionApiKeyRegistryServer).DeletePredictionApiKeyRegistration(ctx, req.(*DeletePredictionApiKeyRegistrationRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _PredictionApiKeyRegistry_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.recommendationengine.v1beta1.PredictionApiKeyRegistry",
	HandlerType: (*PredictionApiKeyRegistryServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreatePredictionApiKeyRegistration",
			Handler:    _PredictionApiKeyRegistry_CreatePredictionApiKeyRegistration_Handler,
		},
		{
			MethodName: "ListPredictionApiKeyRegistrations",
			Handler:    _PredictionApiKeyRegistry_ListPredictionApiKeyRegistrations_Handler,
		},
		{
			MethodName: "DeletePredictionApiKeyRegistration",
			Handler:    _PredictionApiKeyRegistry_DeletePredictionApiKeyRegistration_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/recommendationengine/v1beta1/prediction_apikey_registry_service.proto",
}
