// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.26.0
// 	protoc        v3.12.2
// source: cloud/containers/workflow/vulnerability/proto/package.proto

package vulnerability

import (
	reflect "reflect"
	sync "sync"

	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type PackageData struct {
	state         protoimpl.MessageState
	sizeCache     protoimpl.SizeCache
	unknownFields protoimpl.UnknownFields

	// The package being analysed for vulnerabilities
	Package string `protobuf:"bytes,1,opt,name=package,proto3" json:"package,omitempty"`
	// The version of the package being analysed
	Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	// The OS affected by a vulnerability
	// This field is deprecated and the information is in cpe_uri
	//
	// Deprecated: Do not use.
	Os string `protobuf:"bytes,3,opt,name=os,proto3" json:"os,omitempty"`
	// The version of the OS
	// This field is deprecated and the information is in cpe_uri
	//
	// Deprecated: Do not use.
	OsVersion string `protobuf:"bytes,4,opt,name=os_version,json=osVersion,proto3" json:"os_version,omitempty"`
	// The cpe_uri in [cpe format] (https://cpe.mitre.org/specification/) in
	// which the vulnerability may manifest.  Examples include distro or storage
	// location for vulnerable jar.
	CpeUri string `protobuf:"bytes,5,opt,name=cpe_uri,json=cpeUri,proto3" json:"cpe_uri,omitempty"`
	Unused string `protobuf:"bytes,6,opt,name=unused,proto3" json:"unused,omitempty"`
}

func (x *PackageData) Reset() {
	*x = PackageData{}
	if protoimpl.UnsafeEnabled {
		mi := &file_cloud_containers_workflow_vulnerability_proto_package_proto_msgTypes[0]
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		ms.StoreMessageInfo(mi)
	}
}

func (x *PackageData) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*PackageData) ProtoMessage() {}

func (x *PackageData) ProtoReflect() protoreflect.Message {
	mi := &file_cloud_containers_workflow_vulnerability_proto_package_proto_msgTypes[0]
	if protoimpl.UnsafeEnabled && x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use PackageData.ProtoReflect.Descriptor instead.
func (*PackageData) Descriptor() ([]byte, []int) {
	return file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescGZIP(), []int{0}
}

func (x *PackageData) GetPackage() string {
	if x != nil {
		return x.Package
	}
	return ""
}

func (x *PackageData) GetVersion() string {
	if x != nil {
		return x.Version
	}
	return ""
}

// Deprecated: Do not use.
func (x *PackageData) GetOs() string {
	if x != nil {
		return x.Os
	}
	return ""
}

// Deprecated: Do not use.
func (x *PackageData) GetOsVersion() string {
	if x != nil {
		return x.OsVersion
	}
	return ""
}

func (x *PackageData) GetCpeUri() string {
	if x != nil {
		return x.CpeUri
	}
	return ""
}

func (x *PackageData) GetUnused() string {
	if x != nil {
		return x.Unused
	}
	return ""
}

var File_cloud_containers_workflow_vulnerability_proto_package_proto protoreflect.FileDescriptor

var file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDesc = []byte{
	0x0a, 0x3b, 0x63, 0x6c, 0x6f, 0x75, 0x64, 0x2f, 0x63, 0x6f, 0x6e, 0x74, 0x61, 0x69, 0x6e, 0x65,
	0x72, 0x73, 0x2f, 0x77, 0x6f, 0x72, 0x6b, 0x66, 0x6c, 0x6f, 0x77, 0x2f, 0x76, 0x75, 0x6c, 0x6e,
	0x65, 0x72, 0x61, 0x62, 0x69, 0x6c, 0x69, 0x74, 0x79, 0x2f, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x2f,
	0x70, 0x61, 0x63, 0x6b, 0x61, 0x67, 0x65, 0x2e, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x12, 0x36, 0x63,
	0x6c, 0x6f, 0x75, 0x64, 0x5f, 0x63, 0x6f, 0x6e, 0x74, 0x61, 0x69, 0x6e, 0x65, 0x72, 0x73, 0x2e,
	0x77, 0x6f, 0x72, 0x6b, 0x66, 0x6c, 0x6f, 0x77, 0x2e, 0x61, 0x6e, 0x61, 0x6c, 0x79, 0x73, 0x69,
	0x73, 0x2e, 0x76, 0x75, 0x6c, 0x6e, 0x65, 0x72, 0x61, 0x62, 0x69, 0x6c, 0x69, 0x74, 0x79, 0x2e,
	0x70, 0x72, 0x6f, 0x74, 0x6f, 0x22, 0xa9, 0x01, 0x0a, 0x0b, 0x50, 0x61, 0x63, 0x6b, 0x61, 0x67,
	0x65, 0x44, 0x61, 0x74, 0x61, 0x12, 0x18, 0x0a, 0x07, 0x70, 0x61, 0x63, 0x6b, 0x61, 0x67, 0x65,
	0x18, 0x01, 0x20, 0x01, 0x28, 0x09, 0x52, 0x07, 0x70, 0x61, 0x63, 0x6b, 0x61, 0x67, 0x65, 0x12,
	0x18, 0x0a, 0x07, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x02, 0x20, 0x01, 0x28, 0x09,
	0x52, 0x07, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x12, 0x12, 0x0a, 0x02, 0x6f, 0x73, 0x18,
	0x03, 0x20, 0x01, 0x28, 0x09, 0x42, 0x02, 0x18, 0x01, 0x52, 0x02, 0x6f, 0x73, 0x12, 0x21, 0x0a,
	0x0a, 0x6f, 0x73, 0x5f, 0x76, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e, 0x18, 0x04, 0x20, 0x01, 0x28,
	0x09, 0x42, 0x02, 0x18, 0x01, 0x52, 0x09, 0x6f, 0x73, 0x56, 0x65, 0x72, 0x73, 0x69, 0x6f, 0x6e,
	0x12, 0x17, 0x0a, 0x07, 0x63, 0x70, 0x65, 0x5f, 0x75, 0x72, 0x69, 0x18, 0x05, 0x20, 0x01, 0x28,
	0x09, 0x52, 0x06, 0x63, 0x70, 0x65, 0x55, 0x72, 0x69, 0x12, 0x16, 0x0a, 0x06, 0x75, 0x6e, 0x75,
	0x73, 0x65, 0x64, 0x18, 0x06, 0x20, 0x01, 0x28, 0x09, 0x52, 0x06, 0x75, 0x6e, 0x75, 0x73, 0x65,
	0x64, 0x42, 0xdc, 0x02, 0x0a, 0x3b, 0x63, 0x6f, 0x6d, 0x2e, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65,
	0x2e, 0x63, 0x6c, 0x6f, 0x75, 0x64, 0x2e, 0x63, 0x6f, 0x6e, 0x74, 0x61, 0x69, 0x6e, 0x65, 0x72,
	0x73, 0x2e, 0x77, 0x6f, 0x72, 0x6b, 0x66, 0x6c, 0x6f, 0x77, 0x2e, 0x61, 0x6e, 0x61, 0x6c, 0x79,
	0x73, 0x69, 0x73, 0x2e, 0x76, 0x75, 0x6c, 0x6e, 0x65, 0x72, 0x61, 0x62, 0x69, 0x6c, 0x69, 0x74,
	0x79, 0x42, 0x10, 0x50, 0x61, 0x63, 0x6b, 0x61, 0x67, 0x65, 0x44, 0x61, 0x74, 0x61, 0x50, 0x72,
	0x6f, 0x74, 0x6f, 0x50, 0x01, 0x5a, 0x56, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x67, 0x6f,
	0x6c, 0x61, 0x6e, 0x67, 0x2e, 0x6f, 0x72, 0x67, 0x2f, 0x67, 0x65, 0x6e, 0x70, 0x72, 0x6f, 0x74,
	0x6f, 0x2f, 0x67, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x61, 0x70, 0x69, 0x73, 0x2f, 0x63, 0x6c, 0x6f,
	0x75, 0x64, 0x2f, 0x63, 0x6f, 0x6e, 0x74, 0x61, 0x69, 0x6e, 0x65, 0x72, 0x73, 0x2f, 0x77, 0x6f,
	0x72, 0x6b, 0x66, 0x6c, 0x6f, 0x77, 0x2f, 0x61, 0x6e, 0x61, 0x6c, 0x79, 0x73, 0x69, 0x73, 0x3b,
	0x76, 0x75, 0x6c, 0x6e, 0x65, 0x72, 0x61, 0x62, 0x69, 0x6c, 0x69, 0x74, 0x79, 0xaa, 0x02, 0x37,
	0x47, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x2e, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x2e, 0x43, 0x6f, 0x6e,
	0x74, 0x61, 0x69, 0x6e, 0x65, 0x72, 0x73, 0x2e, 0x57, 0x6f, 0x72, 0x6b, 0x66, 0x6c, 0x6f, 0x77,
	0x2e, 0x41, 0x6e, 0x61, 0x6c, 0x79, 0x73, 0x69, 0x73, 0x2e, 0x56, 0x75, 0x6c, 0x6e, 0x65, 0x72,
	0x61, 0x62, 0x69, 0x6c, 0x69, 0x74, 0x79, 0xca, 0x02, 0x37, 0x47, 0x6f, 0x6f, 0x67, 0x6c, 0x65,
	0x5c, 0x43, 0x6c, 0x6f, 0x75, 0x64, 0x5c, 0x43, 0x6f, 0x6e, 0x74, 0x61, 0x69, 0x6e, 0x65, 0x72,
	0x73, 0x5c, 0x57, 0x6f, 0x72, 0x6b, 0x66, 0x6c, 0x6f, 0x77, 0x5c, 0x41, 0x6e, 0x61, 0x6c, 0x79,
	0x73, 0x69, 0x73, 0x5c, 0x56, 0x75, 0x6c, 0x6e, 0x65, 0x72, 0x61, 0x62, 0x69, 0x6c, 0x69, 0x74,
	0x79, 0xea, 0x02, 0x3c, 0x47, 0x6f, 0x6f, 0x67, 0x6c, 0x65, 0x3a, 0x3a, 0x43, 0x6c, 0x6f, 0x75,
	0x64, 0x3a, 0x3a, 0x43, 0x6f, 0x6e, 0x74, 0x61, 0x69, 0x6e, 0x65, 0x72, 0x73, 0x3a, 0x3a, 0x57,
	0x6f, 0x72, 0x6b, 0x66, 0x6c, 0x6f, 0x77, 0x3a, 0x3a, 0x41, 0x6e, 0x61, 0x6c, 0x79, 0x73, 0x69,
	0x73, 0x3a, 0x3a, 0x56, 0x75, 0x6c, 0x6e, 0x65, 0x72, 0x61, 0x62, 0x69, 0x6c, 0x69, 0x74, 0x79,
	0x62, 0x06, 0x70, 0x72, 0x6f, 0x74, 0x6f, 0x33,
}

var (
	file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescOnce sync.Once
	file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescData = file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDesc
)

func file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescGZIP() []byte {
	file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescOnce.Do(func() {
		file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescData = protoimpl.X.CompressGZIP(file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescData)
	})
	return file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDescData
}

var file_cloud_containers_workflow_vulnerability_proto_package_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_cloud_containers_workflow_vulnerability_proto_package_proto_goTypes = []interface{}{
	(*PackageData)(nil), // 0: cloud_containers.workflow.analysis.vulnerability.proto.PackageData
}
var file_cloud_containers_workflow_vulnerability_proto_package_proto_depIdxs = []int32{
	0, // [0:0] is the sub-list for method output_type
	0, // [0:0] is the sub-list for method input_type
	0, // [0:0] is the sub-list for extension type_name
	0, // [0:0] is the sub-list for extension extendee
	0, // [0:0] is the sub-list for field type_name
}

func init() { file_cloud_containers_workflow_vulnerability_proto_package_proto_init() }
func file_cloud_containers_workflow_vulnerability_proto_package_proto_init() {
	if File_cloud_containers_workflow_vulnerability_proto_package_proto != nil {
		return
	}
	if !protoimpl.UnsafeEnabled {
		file_cloud_containers_workflow_vulnerability_proto_package_proto_msgTypes[0].Exporter = func(v interface{}, i int) interface{} {
			switch v := v.(*PackageData); i {
			case 0:
				return &v.state
			case 1:
				return &v.sizeCache
			case 2:
				return &v.unknownFields
			default:
				return nil
			}
		}
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDesc,
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_cloud_containers_workflow_vulnerability_proto_package_proto_goTypes,
		DependencyIndexes: file_cloud_containers_workflow_vulnerability_proto_package_proto_depIdxs,
		MessageInfos:      file_cloud_containers_workflow_vulnerability_proto_package_proto_msgTypes,
	}.Build()
	File_cloud_containers_workflow_vulnerability_proto_package_proto = out.File
	file_cloud_containers_workflow_vulnerability_proto_package_proto_rawDesc = nil
	file_cloud_containers_workflow_vulnerability_proto_package_proto_goTypes = nil
	file_cloud_containers_workflow_vulnerability_proto_package_proto_depIdxs = nil
}
